/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2017 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.ui.prototype;

import static org.fortiss.tooling.base.layout.DefaultLayoutConstants.DEFAULT_SHAPE_MINIMUM_HEIGHT;
import static org.fortiss.tooling.base.layout.DefaultLayoutConstants.DEFAULT_SHAPE_MINIMUM_WIDTH;
import static org.fortiss.tooling.base.ui.utils.LayoutDataUIUtils.setConnectorPosition;
import static org.fortiss.tooling.base.utils.LayoutDataUtils.setNodeBounds;
import static org.fortiss.tooling.base.utils.LayoutDataUtils.setNodePosition;
import static org.fortiss.tooling.base.utils.LayoutModelElementFactory.createRectangle;

import org.fortiss.af3.platform.raspberry.model.ActuatorPWM;
import org.fortiss.af3.platform.raspberry.model.CanBus;
import org.fortiss.af3.platform.raspberry.model.CanConnector;
import org.fortiss.af3.platform.raspberry.model.GPI;
import org.fortiss.af3.platform.raspberry.model.GPO;
import org.fortiss.af3.platform.raspberry.model.RaspberryPi;
import org.fortiss.af3.platform.raspberry.model.SensorIMU;
import org.fortiss.af3.platform.raspberry.model.SensorLaserRangeFinder;
import org.fortiss.af3.platform.raspberry.model.SensorLaserScanner;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button1;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button2;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button3;
import org.fortiss.af3.platform.raspberry.model.gamepad.Button4;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonL1;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonL2;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonR1;
import org.fortiss.af3.platform.raspberry.model.gamepad.ButtonR2;
import org.fortiss.af3.platform.raspberry.model.gamepad.Left_StickX_Position;
import org.fortiss.af3.platform.raspberry.model.gamepad.Left_StickY_Position;
import org.fortiss.af3.platform.raspberry.model.gamepad.Right_StickX_Position;
import org.fortiss.af3.platform.raspberry.model.gamepad.Right_StickY_Position;
import org.fortiss.af3.platform.raspberry.util.RaspberryModelElementFactory;
import org.fortiss.tooling.kernel.extension.base.PrototypeProviderBase;
import org.fortiss.tooling.kernel.extension.data.PrototypeCategory;

/**
 * 
 * @author eder
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating RED Hash:
 */
public class ProtoypeProvider extends PrototypeProviderBase {

	/** Stores the category to display for these prototypes. */
	protected final static String CATEGORY_NAME = "RaspberryPI Platform";
	/** Category for gamepad elements. */
	protected final static String GAMEPAD = "Gamepad";

	/** {@inheritDoc} */
	@Override
	protected void registerPrototypes() {
		RaspberryPi pi = RaspberryModelElementFactory.createRaspberryPi();
		registerPrimaryPrototype("RaspberryPi", pi, CATEGORY_NAME);
		PrototypeCategory prototypeCategory = registerPrototypeCategory(CATEGORY_NAME);
		registerPrototypeCategory(prototypeCategory, GAMEPAD);

		CanBus bus = RaspberryModelElementFactory.createCanBus();
		setNodeBounds(bus,
				createRectangle(0, 0, DEFAULT_SHAPE_MINIMUM_WIDTH, DEFAULT_SHAPE_MINIMUM_HEIGHT));
		registerPrototype("CanBus", bus, CATEGORY_NAME);

		CanConnector con = RaspberryModelElementFactory.createCanConnector();
		setNodePosition(con, 0, 0);
		setConnectorPosition(con, 0, 0);
		registerPrototype("CanConnector", con, CATEGORY_NAME);

		// SensorConnector sensor = RaspberryModelElementFactory.createSensorConnector();
		// setNodePosition(sensor, 0, 0);
		// setConnectorPosition(sensor, 0, 0);
		// registerPrototype("GenericPI_Sensor", sensor, CATEGORY_NAME);

		SensorIMU imu = RaspberryModelElementFactory.createSensorIMU();
		setNodePosition(imu, 0, 0);
		setConnectorPosition(imu, 0, 0);
		registerPrototype("IMU_Sensor", imu, CATEGORY_NAME);

		SensorLaserRangeFinder slrf = RaspberryModelElementFactory.createSensorLaserRangeFinder();
		setNodePosition(slrf, 0, 0);
		setConnectorPosition(slrf, 0, 0);
		registerPrototype("LaserRangeFinder_Sensor", slrf, CATEGORY_NAME);

		SensorLaserScanner sls = RaspberryModelElementFactory.createSensorLaserScanner();
		setNodePosition(sls, 0, 0);
		setConnectorPosition(sls, 0, 0);
		registerPrototype("LaserScanner_Sensor", sls, CATEGORY_NAME);

		// SensorGamepad pad = RaspberryModelElementFactory.createGamepadSensor();
		// setNodePosition(pad, 0, 0);
		// setConnectorPosition(pad, 0, 0);
		// registerPrototype("Gamepad_Sensor", pad, CATEGORY_NAME);

		// ActuatorConnector actuator = RaspberryModelElementFactory.createActuatorConnector();
		// setNodePosition(actuator, 0, 0);
		// setConnectorPosition(actuator, 0, 0);
		// registerPrototype("GenericPI_Actuator", actuator, CATEGORY_NAME);

		ActuatorPWM pwm = RaspberryModelElementFactory.createActuatorPWM();
		setNodePosition(pwm, 0, 0);
		setConnectorPosition(pwm, 0, 0);
		registerPrototype("PWM_Actuator", pwm, CATEGORY_NAME);

		GPI gpi = RaspberryModelElementFactory.createGPI();
		setNodePosition(gpi, 0, 0);
		setConnectorPosition(gpi, 0, 0);
		registerPrototype("GPI", gpi, CATEGORY_NAME);

		GPO gpo = RaspberryModelElementFactory.createGPO();
		setNodePosition(gpo, 0, 0);
		setConnectorPosition(gpo, 0, 0);
		registerPrototype("GPO", gpo, CATEGORY_NAME);

		Button1 button1 = RaspberryModelElementFactory.createButton1();
		setNodePosition(button1, 0, 0);
		setConnectorPosition(button1, 0, 0);
		registerPrototype(button1.getName(), button1, GAMEPAD);

		Button2 button2 = RaspberryModelElementFactory.createButton2();
		setNodePosition(button2, 0, 0);
		setConnectorPosition(button2, 0, 0);
		registerPrototype(button2.getName(), button2, GAMEPAD);

		Button3 button3 = RaspberryModelElementFactory.createButton3();
		setNodePosition(button3, 0, 0);
		setConnectorPosition(button3, 0, 0);
		registerPrototype(button3.getName(), button3, GAMEPAD);

		Button4 button4 = RaspberryModelElementFactory.createButton4();
		setNodePosition(button4, 0, 0);
		setConnectorPosition(button4, 0, 0);
		registerPrototype(button4.getName(), button4, GAMEPAD);

		ButtonL1 buttonL1 = RaspberryModelElementFactory.createButtonL1();
		setNodePosition(buttonL1, 0, 0);
		setConnectorPosition(buttonL1, 0, 0);
		registerPrototype(buttonL1.getName(), buttonL1, GAMEPAD);

		ButtonL2 buttonL2 = RaspberryModelElementFactory.createButtonL2();
		setNodePosition(buttonL2, 0, 0);
		setConnectorPosition(buttonL2, 0, 0);
		registerPrototype(buttonL2.getName(), buttonL2, GAMEPAD);

		ButtonR1 buttonR1 = RaspberryModelElementFactory.createButtonR1();
		setNodePosition(buttonR1, 0, 0);
		setConnectorPosition(buttonR1, 0, 0);
		registerPrototype(buttonR1.getName(), buttonR1, GAMEPAD);

		ButtonR2 buttonR2 = RaspberryModelElementFactory.createButtonR2();
		setNodePosition(buttonR2, 0, 0);
		setConnectorPosition(buttonR2, 0, 0);
		registerPrototype(buttonR2.getName(), buttonR2, GAMEPAD);

		Left_StickX_Position Left_StickX = RaspberryModelElementFactory.createLeftStickX();
		setNodePosition(Left_StickX, 0, 0);
		setConnectorPosition(Left_StickX, 0, 0);
		registerPrototype(Left_StickX.getName(), Left_StickX, GAMEPAD);

		Left_StickY_Position Left_StickY = RaspberryModelElementFactory.createLeftStickY();
		setNodePosition(Left_StickY, 0, 0);
		setConnectorPosition(Left_StickY, 0, 0);
		registerPrototype(Left_StickY.getName(), Left_StickY, GAMEPAD);

		Right_StickX_Position Right_StickX = RaspberryModelElementFactory.createRightStickX();
		setNodePosition(Right_StickX, 0, 0);
		setConnectorPosition(Right_StickX, 0, 0);
		registerPrototype(Right_StickX.getName(), Right_StickX, GAMEPAD);

		Right_StickY_Position Right_StickY = RaspberryModelElementFactory.createRightStickY();
		setNodePosition(Right_StickY, 0, 0);
		setConnectorPosition(Right_StickY, 0, 0);
		registerPrototype(Right_StickY.getName(), Right_StickY, GAMEPAD);

	}
}
